spacepy.datamodel.readJSONMetadata — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »

# spacepy.datamodel.readJSONMetadata

`spacepy.datamodel.` `readJSONMetadata`(fname, **kwargs)

  Read JSON metadata from an ASCII data file

  Parameters: | fname : str Filename to read metadata from
  Returns: | mdata: spacepy.datamodel.SpaceData : SpaceData with the metadata from the file
  Other Parameters:
  | verbose : bool (optional) set verbose output so metadata tree prints on read (default False)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »